@@ -2,6 +2,7 @@ from typing import Optional
 
 import httpx
 
+from nepse.broker.core import BrokerClient
 from nepse.market.core import MarketClient
 from nepse.utils import _ClientWrapperHTTPX
 
@@ -21,6 +22,19 @@ class Client:
             self._client_wrapper, cache_retain_time, use_cache
         )
         self._market_client = MarketClient(self._client_wrapper)
+        self._broker_client = BrokerClient(
+            self._client_wrapper, use_cache, cache_retain_time
+        )
+
+    @property
+    def broker_client(self) -> BrokerClient:
+        """Returns the initialized `BrokerClient`
+
+        Returns:
+            BrokerClient: It is the module through which you can interact with
+            API's brokers.
+        """
+        return self._broker_client
 
     @property
     def security_client(self) -> SecurityClient:
